@@ -46,19 +46,26 @@ async def get_user_profile(url: str, auth: str) -> AuthUser:
 
 
 def get_token_auth_header(auth: str) -> str:
-    """Obtains the Access Token from the Authorization Header
-    """
+    """Obtains the Access Token from the Authorization Header"""
     if not auth:
-        raise UnauthorizedError(detail="Authorization header is expected",)
+        raise UnauthorizedError(
+            detail="Authorization header is expected",
+        )
 
     parts = auth.split()
 
     if parts[0].lower() != "bearer":
-        raise UnauthorizedError(detail="Authorization header must start with Bearer",)
+        raise UnauthorizedError(
+            detail="Authorization header must start with Bearer",
+        )
     elif len(parts) == 1:
-        raise UnauthorizedError(detail="Token not found",)
+        raise UnauthorizedError(
+            detail="Token not found",
+        )
     elif len(parts) > 2:
-        raise UnauthorizedError(detail="Authorization header must be Bearer token",)
+        raise UnauthorizedError(
+            detail="Authorization header must be Bearer token",
+        )
 
     token = parts[1]
     return token
@@ -67,9 +74,7 @@ def get_token_auth_header(auth: str) -> str:
 async def decode_token(auth: str):
     settings = get_settings()
     token = get_token_auth_header(auth)
-    jwks = await async_get(
-        f"https://{settings.AUTH0_DOMAIN}/.well-known/jwks.json", json_only=True
-    )
+    jwks = await async_get(f"https://{settings.AUTH0_DOMAIN}/.well-known/jwks.json", json_only=True)
 
     unverified_header = jwt.get_unverified_header(token)
     rsa_key: dict = {}
@@ -92,22 +97,26 @@ async def decode_token(auth: str):
                 issuer="https://" + settings.AUTH0_DOMAIN + "/",
             )
         except jwt.ExpiredSignatureError:
-            raise UnauthorizedError(detail="token is expired",)
+            raise UnauthorizedError(
+                detail="token is expired",
+            )
         except jwt.JWTClaimsError:
             raise UnauthorizedError(
                 detail="incorrect claims, please check the audience and issuer",
             )
         except Exception:
-            raise UnauthorizedError(detail="Unable to parse authentication token.",)
+            raise UnauthorizedError(
+                detail="Unable to parse authentication token.",
+            )
 
         return payload
 
-    raise UnauthorizedError(detail="Unable to find appropriate key",)
+    raise UnauthorizedError(
+        detail="Unable to find appropriate key",
+    )
 
 
-async def get_user(
-    payload: dict, token: str, get_profile: bool = True
-) -> Optional[AuthUser]:
+async def get_user(payload: dict, token: str, get_profile: bool = True) -> Optional[AuthUser]:
     settings = get_settings()
     user: Optional[AuthUser] = None
     token_scopes: List[str] = []
@@ -116,24 +125,16 @@ async def get_user(
     if "permissions" in payload and payload.get("permissions") is not None:
         token_scopes = payload["permissions"]
 
-    if (
-        settings.ROLES_NAMESPACE in payload
-        and payload.get(settings.ROLES_NAMESPACE) is not None
-    ):
+    if settings.ROLES_NAMESPACE in payload and payload.get(settings.ROLES_NAMESPACE) is not None:
         roles = payload[settings.ROLES_NAMESPACE]
 
     if "sub" in payload:
-        if (
-            get_profile
-            and "aud" in payload
-            and len(payload["aud"]) > 1
-            and "userinfo" in payload["aud"][1]
-        ):
+        if get_profile and "aud" in payload and len(payload["aud"]) > 1 and "userinfo" in payload["aud"][1]:
             try:
                 user = await get_user_profile(payload["aud"][1], token)
             except Exception as err:
                 LOG.warning(
-                    f"Something went wrong retieving user profile falling back to creating user from "
+                    "Something went wrong retieving user profile falling back to creating user from "
                     + f"the payload. Error: {err}"
                 )
                 user = AuthUser(**payload)
@@ -163,19 +164,23 @@ async def get_current_user(
 
     except (JWTError, ValidationError) as e:
         LOG.error("Could not validate credentials. {}", str(e))
-        raise UnauthorizedError(detail="Could not validate credentials.",)
+        raise UnauthorizedError(
+            detail="Could not validate credentials.",
+        )
 
     if not user:
-        raise UnauthorizedError(detail="Invalid authentication credentials.",)
+        raise UnauthorizedError(
+            detail="Invalid authentication credentials.",
+        )
 
     if settings.ENABLE_SCOPES:
         for scope in security_scopes.scopes:
             if scope not in user.scopes and scope not in user.roles:
-                raise ForbiddenError(detail="Not enough permissions",)
+                raise ForbiddenError(
+                    detail="Not enough permissions",
+                )
     return user
 
 
-async def get_auth_simple(
-    security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)
-) -> AuthUser:
+async def get_auth_simple(security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)) -> AuthUser:
     return await get_current_user(security_scopes, token, False)
