@@ -23,7 +23,7 @@ class DatabaseType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "0.13.2"
+    VERSION: str = "1.0.0"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -65,12 +65,12 @@ class Settings(BaseSettings):
     DATABASE_TYPE: DatabaseType = DatabaseType.GCP_FIRESTORE  # FIRESTORE or MONGODB
     STORAGE_TYPE: StorageType = StorageType.GCP_STORAGE
     USE_FIREBASE: bool = (
-        STORAGE_TYPE == StorageType.FIREBASE_STORAGE
-        or DATABASE_TYPE == DatabaseType.GCP_FIRESTORE
+        STORAGE_TYPE == StorageType.FIREBASE_STORAGE or DATABASE_TYPE == DatabaseType.GCP_FIRESTORE
     )
 
     MONGODB_DSN: Optional[str] = None
     MONGODB_DBNAME: Optional[str] = None
+    MONGO_AUTO_CONNECT: bool = True
     mongodb_min_pool_size: int = 0
     mongodb_max_pool_size: int = 100
     TZ: str = "Australia/Perth"
