@@ -1,6 +1,8 @@
+from enum import unique
 from typing import Any, List, Optional, Tuple, Type
 
 from bson import CodecOptions
+from bson.objectid import ObjectId
 from motor.motor_asyncio import AsyncIOMotorClient
 
 # from pymongo.client_session import ClientSession
@@ -8,12 +10,14 @@ from pymongo.collection import Collection
 
 # from pymongo.cursor import Cursor
 # from pymongo.results import InsertOneResult, UpdateResult
+import pymongo
 
 from fa_common import get_current_app, get_timezone
 from fa_common import logger as LOG
 
 from .base_client import BaseClient
 from .models import (
+    DBIndex,
     DeleteResult,
     FireOffset,
     Operator,
@@ -24,7 +28,6 @@ from .models import (
 )
 
 
-# FIXME missing base class methods
 class MongoDBClient(BaseClient):
     """
     Singleton client for interacting with MongoDB.
@@ -37,6 +40,7 @@ class MongoDBClient(BaseClient):
 
     __instance = None
     mongodb: AsyncIOMotorClient = None
+    codec_options: CodecOptions = None
 
     def __new__(cls) -> "MongoDBClient":
         if cls.__instance is None:
@@ -48,10 +52,10 @@ class MongoDBClient(BaseClient):
         return cls.__instance
 
     def get_collection(self, collection_name: str) -> Collection:
-        return self.mongodb.get_collection(
-            collection_name,
-            # codec_options=self.codec_options
-        )
+        return self.mongodb.get_collection(collection_name, codec_options=self.codec_options)
+
+    async def delete_collection(self, collection_name: str):
+        await self.mongodb.drop_collection(collection_name)
 
     async def insert(
         self,
@@ -61,14 +65,15 @@ class MongoDBClient(BaseClient):
         session: Any = None,
     ) -> WriteResult:
         data = model.dict(include=include, exclude=exclude)
-        data["_id"] = data.pop("id")
+        _id = data.pop("id", None)
+        if _id is not None:
+            data["_id"]
         collection_name = model.get_db_collection()
         collection = self.get_collection(collection_name)
         result = await collection.insert_one(data, session=session)
 
         LOG.info("Insert Result: {}", result)
-        # FIXME: Correct result return
-        return WriteResult()
+        return WriteResult(new_id=str(result.inserted_id), transform_results=[result])
 
     async def count(self, model: Type[DocumentDBModel], session: Any = None) -> int:
 
@@ -88,12 +93,10 @@ class MongoDBClient(BaseClient):
         self, model: Type[DocumentDBModel], _id: str, data: dict, session: Any = None
     ) -> WriteResult:
         data.pop("id", None)
-        if _id is not None:
-            data["_id"] = _id
 
         collection_name = model.get_db_collection()
         collection = self.get_collection(collection_name)
-        await collection.update_one(filter={"_id": _id}, update=data, session=session)
+        await collection.update_one(filter={"_id": ObjectId(_id)}, update={"$set": data}, session=session)
         return WriteResult()
 
     # FIXME: Add this back once the firstore version has been fixed and added
@@ -105,7 +108,7 @@ class MongoDBClient(BaseClient):
     #         filter_kwargs["_id"] = _id
 
     #     collection_name = model.get_db_collection()
-    #     collection = self.get_collection(collection_name)
+    #     collection = self.get_collection(collection_name)users
     #     res = await collection.update_many(filter_kwargs, kwargs, session=session)
     #     return res
 
@@ -115,7 +118,7 @@ class MongoDBClient(BaseClient):
 
         collection_name = model.get_db_collection()
         collection = self.get_collection(collection_name)
-        res = await collection.find_one(_id=_id, session=session)
+        res = await collection.find_one(filter={"_id": ObjectId(_id)}, session=session)
         if res is None:
             return None
 
@@ -131,11 +134,64 @@ class MongoDBClient(BaseClient):
         fire_offset: FireOffset = None,
     ) -> List[DocumentDBModel]:
 
-        # _id = kwargs.pop("id", None)
-        # if _id is not None:
-        #     kwargs["_id"] = _id
-
         collection_name = model.get_db_collection()
+        results = await self.list_dict(collection_name, where, _limit, _sort, mongo_offset, fire_offset)
+
+        return [model(**res) for res in results]
+
+    def generate_id(self, collection_name: str) -> str:
+        """
+        Generator of IDs for newly created MongoDB rows.
+        :return: `bit_size` long int
+        """
+        return ""
+
+    async def find_one(
+        self,
+        model: Type[DocumentDBModel],
+        where: List[WhereCondition] = [],
+        session: Any = None,
+    ) -> Optional[DocumentDBModel]:
+        results = await self.list(model, where, 1)
+        if len(results) > 0:
+            return results[0]
+        else:
+            return None
+
+    async def find_one_dict(
+        self,
+        collection_name: str,
+        where: List[WhereCondition] = [],
+        session: Any = None,
+    ) -> Optional[dict]:
+        results = await self.list_dict(collection_name, where, 1)
+        if len(results) > 0:
+            return results[0]
+        else:
+            return None
+
+    async def get_dict(
+        self,
+        collection_name: str,
+        _id: str,
+        session: Any = None,
+    ) -> Optional[dict]:
+        collection = self.get_collection(collection_name)
+        res = await collection.find_one(_id=_id, session=session)
+        if res is None:
+            return None
+
+        return res
+
+    async def list_dict(
+        self,
+        collection_name: str,
+        where: List[WhereCondition] = [],
+        _limit: int = 0,
+        _sort: List[Tuple[str, SortOrder]] = None,
+        mongo_offset: int = 0,
+        fire_offset: FireOffset = None,
+    ) -> List[dict]:
         collection = self.get_collection(collection_name)
 
         filter_dict = {}
@@ -152,8 +208,16 @@ class MongoDBClient(BaseClient):
         if _sort is not None:
             for sort in _sort:
                 finder.sort(sort[0], sort[1])
-        results = await finder.to_list()
-        models: List[DocumentDBModel] = []
-        for res in results:
-            models.append(model(**res))
-        return models
+        docs = await finder.to_list(None)
+        return docs
+
+    async def create_indexes(self, index: List[DBIndex], collection: str) -> Optional[List[str]]:
+        c = self.get_collection(collection)
+        mongo_indexes = []
+        for ind in index:
+            fields = [
+                (i[0], pymongo.ASCENDING if i[0] == SortOrder.ASCENDING else pymongo.DESCENDING)
+                for i in ind.index_fields
+            ]
+            mongo_indexes.append(pymongo.IndexModel(fields, unique=ind.unique))
+        return await c.create_indexes(mongo_indexes)
