@@ -127,3 +127,21 @@ class NotFoundError(HTTPException):
         super().__init__(
             error_name="Not Found Error", status_code=404, detail=detail, fields=fields,
         )
+
+
+class AlreadyExistsError(HTTPException):
+    def __init__(
+        self, detail: Any = "Already Exists.", fields: List[Dict] = None,
+    ):
+        """
+        409 Conflict HTTP Exception with support for custom error code.
+
+        :param error_code: Custom error code, unique throughout the app
+        :param detail: detailed message of the error
+        """
+        super().__init__(
+            error_name="Already Exists Error",
+            status_code=409,
+            detail=detail,
+            fields=fields,
+        )
