@@ -349,8 +349,10 @@ class FirebaseStorageClient(GoogleStorageClient):
         LOG.warning("Trying to delete file {} that doesn't exist", blob.name)
 
     async def delete_bucket(self, name: str):
-        blobs = await force_async(self.bucket.list_blobs)(
-            prefix=get_settings().BUCKET_USER_FOLDER + name + "/"
+        blobs = list(
+            await force_async(self.bucket.list_blobs)(
+                prefix=get_settings().BUCKET_USER_FOLDER + name + "/"
+            )
         )
         await force_async(self.bucket.delete_blobs)(
             blobs, on_error=self.log_error_not_found
